@@ -5,20 +5,11 @@
 */
 
 #include "modulemanager.h"
-#include "../config.h"
 #include "module.h"
 #include "server.h"
 
-#if USE_GSETTINGS
 #include "gsettingsitem.h"
-
 #define PA_SETTINGS_PATH_MODULES "/org/freedesktop/pulseaudio/module-groups"
-#endif
-
-#if USE_GCONF
-#include "gconfitem.h"
-#define PA_SETTINGS_PATH_MODULES "/system/pulseaudio/modules"
-#endif
 
 #include <QTimer>
 #include <chrono>
@@ -27,13 +18,7 @@ using namespace std::chrono_literals;
 
 namespace QPulseAudio
 {
-#if USE_GCONF || USE_GSETTINGS
-
-#if USE_GSETTINGS
 class ConfigModule : public GSettingsItem
-#elif USE_GCONF
-class ConfigModule : public GConfItem
-#endif
 {
 public:
     ConfigModule(const QString &configName, const QString &moduleName, QObject *parent);
@@ -45,15 +30,8 @@ private:
 };
 
 ConfigModule::ConfigModule(const QString &configName, const QString &moduleName, QObject *parent)
-    :
-#if USE_GSETTINGS
-    GSettingsItem(QStringLiteral(PA_SETTINGS_PATH_MODULES "/") + configName + QStringLiteral("/"), parent)
-    ,
-#elif USE_GCONF
-    GConfItem(QStringLiteral(PA_SETTINGS_PATH_MODULES "/") + configName, parent)
-    ,
-#endif
-    m_moduleName(moduleName)
+    : GSettingsItem(QStringLiteral(PA_SETTINGS_PATH_MODULES "/") + configName + QStringLiteral("/"), parent)
+    , m_moduleName(moduleName)
 {
 }
 
@@ -76,24 +54,20 @@ void ConfigModule::setEnabled(bool enabled, const QVariant &args)
     set(QStringLiteral("locked"), false);
 }
 
-#endif
-
 ModuleManager::ModuleManager(QObject *parent)
     : QObject(parent)
 {
-#if USE_GCONF || USE_GSETTINGS
-    m_combineSinks = new ConfigModule(QStringLiteral("combine"), QStringLiteral("module-combine"), this);
+    m_combineSinks = new ConfigModule(QStringLiteral("combine"), QStringLiteral("module-combine-sink"), this);
     m_switchOnConnect = new ConfigModule(QStringLiteral("switch-on-connect"), QStringLiteral("module-switch-on-connect"), this);
     m_deviceManager = new ConfigModule(QStringLiteral("device-manager"), QStringLiteral("module-device-manager"), this);
 
     connect(m_combineSinks, &ConfigModule::subtreeChanged, this, &ModuleManager::combineSinksChanged);
     connect(m_switchOnConnect, &ConfigModule::subtreeChanged, this, &ModuleManager::switchOnConnectChanged);
     connect(m_deviceManager, &ConfigModule::subtreeChanged, this, &ModuleManager::switchOnConnectChanged);
-#endif
 
     connect(Context::instance()->server(), &Server::updated, this, &ModuleManager::serverUpdated);
 
-    QTimer *updateModulesTimer = new QTimer(this);
+    auto *updateModulesTimer = new QTimer(this);
     updateModulesTimer->setInterval(500ms);
     updateModulesTimer->setSingleShot(true);
     connect(updateModulesTimer, &QTimer::timeout, this, &ModuleManager::updateLoadedModules);
@@ -102,64 +76,41 @@ ModuleManager::ModuleManager(QObject *parent)
     updateLoadedModules();
 }
 
-ModuleManager::~ModuleManager(){};
+ModuleManager::~ModuleManager() = default;
+;
 
 bool ModuleManager::settingsSupported() const
 {
     // PipeWire does not (yet) have support for module-switch-on-connect and module-combine-sink
     // Also switching streams is the default there
     // TODO Check whether there is a PipeWire-specific way to do these
-    if (Context::instance()->server()->isPipeWire()) {
-        return false;
-    }
-
-#if USE_GCONF || USE_GSETTINGS
-    return true;
-#else
-    return false;
-#endif
+    return !Context::instance()->server()->isPipeWire();
 }
 
 bool ModuleManager::combineSinks() const
 {
-#if USE_GCONF || USE_GSETTINGS
     return m_combineSinks->isEnabled();
-#else
-    return false;
-#endif
 }
 
 void ModuleManager::setCombineSinks(bool combineSinks)
 {
-#if USE_GCONF || USE_GSETTINGS
     m_combineSinks->setEnabled(combineSinks);
-#else
-    Q_UNUSED(combineSinks()
-#endif
 }
 
 bool ModuleManager::switchOnConnect() const
 {
-#if USE_GCONF || USE_GSETTINGS
     // switch on connect and device-manager do the same task. Only one should be enabled
 
     // Note on the first run m_deviceManager will appear to be disabled even though it's actually running
     // because there is no gconf entry, however m_switchOnConnect will only exist if set by Plasma PA
     // hence only check this entry
     return m_switchOnConnect->isEnabled();
-#else
-    return false;
-#endif
 }
 
 void ModuleManager::setSwitchOnConnect(bool switchOnConnect)
 {
-#if USE_GCONF || USE_GSETTINGS
     m_deviceManager->setEnabled(!switchOnConnect);
     m_switchOnConnect->setEnabled(switchOnConnect);
-#else
-    Q_UNUSED(switchOnConnect)
-#endif
 }
 
 QStringList ModuleManager::loadedModules() const
@@ -184,12 +135,6 @@ bool ModuleManager::configModuleLoaded() const
 
 QString ModuleManager::configModuleName() const
 {
-#if USE_GCONF
-    return QStringLiteral("module-gconf");
-#elif USE_GSETTINGS
     return QStringLiteral("module-gsettings");
-#else
-    return QString();
-#endif
 }
 }
